from setuptools import setup

setup(name='harrix-pyssg',
      version='0.1',
      description='Static site generator',
      packages=['harrixpyssg'],
      author_email='anton.b.sergienko@gmail.com',
      zip_safe=False)